@@ -1,8 +1,10 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, ClassVar
+from collections.abc import Iterable
+from typing import TYPE_CHECKING, Any, ClassVar, Union
 
 from pdm import termui
+from pdm.__version__ import __version__ as pdm_version
 from pdm.cli.commands.base import BaseCommand
 from pdm.cli.options import dry_run_option
 from pdm.signals import post_install, post_lock
@@ -23,6 +25,7 @@ if TYPE_CHECKING:
     from pdm.cli.hooks import HookManager
     from pdm.core import Core
     from pdm.models.candidates import Candidate
+    from pdm.models.repositories.lock import LockedRepository
     from pdm.project import Project
     from pdm.termui import UI
 
@@ -99,7 +102,8 @@ def on_pdm_install_setup_pre_commit(
     project: Project, *, hooks: HookManager, candidates: list[Candidate], dry_run: bool, **_: Any
 ) -> None:
     printer = PDMPrinter(project.core.ui)
-    plugin_config: SyncPreCommitLockConfig = load_config()
+    project_root: Path = project.root
+    plugin_config: SyncPreCommitLockConfig = load_config(project_root / project.PYPROJECT_FILENAME)
     printer.debug("Checking if pre-commit hooks are installed")
 
     if not plugin_config.automatically_install_hooks:
@@ -116,9 +120,19 @@ def on_pdm_install_setup_pre_commit(
     action.execute()
 
 
+if TYPE_CHECKING:
+    Resolution = Union[dict[str, list[Candidate]], dict[str, Candidate]]
+
+
+def select_candidate(candidate: Union[Candidate, list[Candidate]]) -> Candidate | None:
+    if isinstance(candidate, Iterable):
+        return next(iter(candidate), None)
+    return candidate
+
+
 @post_lock.connect
 def on_pdm_lock_check_pre_commit(
-    project: Project, *, resolution: dict[str, Candidate], dry_run: bool, with_prefix: bool = True, **kwargs: Any
+    project: Project, *, resolution: Resolution, dry_run: bool, with_prefix: bool = True, **kwargs: Any
 ) -> None:
     project_root: Path = project.root
     plugin_config: SyncPreCommitLockConfig = load_config(project_root / project.PYPROJECT_FILENAME)
@@ -126,8 +140,12 @@ def on_pdm_lock_check_pre_commit(
 
     file_path = project_root / plugin_config.pre_commit_config_file
     resolved_packages: dict[str, GenericLockedPackage] = {
-        k: GenericLockedPackage(v.name, v.version) for k, v in resolution.items() if v.name and v.version
+        k: GenericLockedPackage(c.name, c.version)
+        for k, v in resolution.items()
+        if (c := select_candidate(v)) and c.name and c.version
     }
+    # Adds pdm itself has it won't be part of the resolved dependencies
+    resolved_packages["pdm"] = GenericLockedPackage("pdm", pdm_version)
     action = SyncPreCommitHooksVersion(
         printer=printer,
         pre_commit_config_file_path=file_path,
@@ -147,6 +165,12 @@ class SyncPreCommitVersionsPDMCommand(BaseCommand):
         dry_run_option.add_to_parser(parser)
 
     def handle(self, project: Project, options: argparse.Namespace) -> None:
-        candidates = project.locked_repository.all_candidates
+        candidates = self._get_locked_repository(project).all_candidates
 
         on_pdm_lock_check_pre_commit(project, resolution=candidates, dry_run=options.dry_run, with_prefix=False)
+
+    def _get_locked_repository(self, project: Project) -> LockedRepository:
+        # `locked_repository` was deprecated in PDM 2.17 favour of `get_locked_repository`, try to use it first to avoid warning
+        if hasattr(project, "get_locked_repository"):
+            return project.get_locked_repository()
+        return project.locked_repository
